@@ -237,8 +237,11 @@ class ConnectionInstance:
         return bytes(buffer)
 
     async def _read_exactly(self, num):
+        data = b''
         try:
-            return await self._stream.receive_some(num)
+            while len(data) < num:
+                data += await self._stream.receive_some(num - len(data))
+            return data
         except (trio.BrokenResourceError, trio.ClosedResourceError):
             self._closed = True
 
@@ -499,7 +502,7 @@ class TrioConnectionPool:
                 # still connected.
                 conn = self._connections.popleft()
         except IndexError:
-            conn = await make_connection(*self._args, **self._kwargs)
+            conn = await make_connection(Connection, *self._args, **self._kwargs)
 
         self._lent_out.add(conn)
         return conn
