@@ -170,7 +170,7 @@ def check_minimum_version(options, minimum_version="1.6", raise_exception=True):
 
 
 DbTable = collections.namedtuple("DbTable", ["db", "table"])
-_tableNameRegex = re.compile(r"^(?P<db>\w+)(\.(?P<table>\w+))?$")
+_tableNameRegex = re.compile(r"^(?P<db>[\w-]+)(\.(?P<table>[\w-]+))?$")
 
 
 class CommonOptionsParser(optparse.OptionParser, object):
@@ -308,7 +308,7 @@ class CommonOptionsParser(optparse.OptionParser, object):
 
                     values.ensure_value(dest, {})[self.metavar.lower()] = value
                 elif action == "get_password":
-                    values[dest] = getpass.getpass("Password for `admin`: ")
+                    values.ensure_value('password', getpass.getpass("Password for `admin`: "))
                 else:
                     super(CommonOptionChecker, self).take_action(
                         action, dest, opt, value, values, parser
